==> lalmetaio-1.2.8.tar.xz: lalmetaio-1.2.8/src/LALMetaIOVCSInfo.h <==
/*
 * LALMetaIOVCSInfo.h - LALMetaIO VCS Information
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with with program; see the file COPYING. If not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 *
 * Copyright (C) 2009-2013 Adam Mercer
 * Copyright (C) 2014 Karl Wette
 */

#ifndef _LALMETAIOVCSINFO_H
#define _LALMETAIOVCSINFO_H

#include <lal/LALVCSInfoType.h>

#ifdef __cplusplus
extern "C" {
#endif

/**
 * \defgroup LALMetaIOVCSInfo_h Header LALMetaIOVCSInfo.h
 * \ingroup lalmetaio_general
 * \brief VCS information for LALMetaIO
 */
/*@{*/

/** \name Global variables for LALMetaIO VCS information */
/*@{*/
extern const char *const lalMetaIOVCSVersion;
extern const char *const lalMetaIOVCSId;
extern const char *const lalMetaIOVCSDate;
extern const char *const lalMetaIOVCSBranch;
extern const char *const lalMetaIOVCSTag;
extern const char *const lalMetaIOVCSAuthor;
extern const char *const lalMetaIOVCSCommitter;
extern const char *const lalMetaIOVCSStatus;
/*@}*/

/** \name Identable global variables for LALMetaIO VCS information */
/*@{*/
extern const char *const lalMetaIOVCSIdentId;
extern const char *const lalMetaIOVCSIdentDate;
extern const char *const lalMetaIOVCSIdentBranch;
extern const char *const lalMetaIOVCSIdentTag;
extern const char *const lalMetaIOVCSIdentAuthor;
extern const char *const lalMetaIOVCSIdentCommitter;
extern const char *const lalMetaIOVCSIdentStatus;
/*@}*/

/** LALMetaIO VCS information */
extern const LALVCSInfo lalMetaIOVCSInfo;

/** List of VCS information for LALMetaIO and its LALSuite dependencies (<tt>NULL</tt>-terminated) */
extern const LALVCSInfo *const lalMetaIOVCSInfoList[32];

/** LALMetaIO <tt>configure</tt> arguments */
extern const char *const lalMetaIOConfigureArgs;

/** LALMetaIO <tt>configure</tt> date */
extern const char *const lalMetaIOConfigureDate;

/** LALMetaIO build date */
extern const char *const lalMetaIOBuildDate;

/** Check LALMetaIO VCS information for compile-time/run-time version mismatch */
#ifndef SWIG /* exclude from SWIG interface */
int XLALMetaIOVCSInfoCheck(void);
#endif /* SWIG */


/*@}*/

#ifdef __cplusplus
}
#endif

#endif /* _LALMETAIOVCSINFO_H */

/*
 * vim: tw=0 ts=2 et
 */

==> lalmetaio-1.3.1.tar.xz: lalmetaio-1.3.1/src/LALMetaIOVCSInfo.h <==
/*
 * Copyright (C) 2014, 2016 Karl Wette
 * Copyright (C) 2009-2013 Adam Mercer
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with with program; see the file COPYING. If not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 */

#ifndef _LALMETAIOVCSINFO_H
#define _LALMETAIOVCSINFO_H

#include <lal/LALVCSInfoType.h>

#ifdef __cplusplus
extern "C" {
#endif

/**
 * \defgroup LALMetaIOVCSInfo_h Header LALMetaIOVCSInfo.h
 * \ingroup lalmetaio_general
 * \brief VCS and build information for LALMetaIO
 */
/*@{*/

/** VCS and build information for LALMetaIO */
extern const LALVCSInfo lalMetaIOVCSInfo;

/** Identable VCS and build information for LALMetaIO */
extern const LALVCSInfo lalMetaIOVCSIdentInfo;

/** <tt>NULL</tt>-terminated list of VCS and build information for LALMetaIO and its dependencies */
extern const LALVCSInfoList lalMetaIOVCSInfoList;

/*@}*/

#ifdef __cplusplus
}
#endif

#endif /* _LALMETAIOVCSINFO_H */
